<?php


namespace Services;


use Exception\Login as Exception;
use Util\InstanceProvider;
use Util\Utilities;
use Util\RepositoryInstance;
use Zeedhi\Framework\Remote\FileUploader\Server;

class PrivacyPolicy
{
    private $fileServerFilesUrl;

    private $zhFileUploader;

    private $nrorg;

    /**
     * PrivacyPolicy constructor.
     * @param $fileServerFilesUrl
     * @param Server $zhFileUploader
     */
    public function __construct($fileServerFilesUrl, Server $zhFileUploader)
    {
        $this->fileServerFilesUrl = $fileServerFilesUrl;
        $this->zhFileUploader = $zhFileUploader;
        $this->nrorg = InstanceProvider::getLibEnvironment()->getCurrentOrganizationId();
    }

    public function uploadPrivacyPolicy($pdfPath)
    {
        $data = array();
        $paramgeralRepository = RepositoryInstance::getParamgeral();
        $paramgeral = $paramgeralRepository->findParamgeral('DSARQPOLPRIV', $this->nrorg);
        $paramgeralRepository->updatePrivacyPolicy($pdfPath, $this->nrorg);
        if(!empty($paramgeral) && $paramgeral['DSARQPOLPRIV']) {
            $this->zhFileUploader->deleteFile($paramgeral['DSARQPOLPRIV']);
        }
        return $this->getDataset(false, $pdfPath);
    }

    public function removePrivacyPolicy()
    {
        $data = array();
        $paramgeralRepository = RepositoryInstance::getParamgeral();
        $paramgeral = $paramgeralRepository->findParamgeral('DSARQPOLPRIV', $this->nrorg);
        $paramgeralRepository->updatePrivacyPolicy(null, $this->nrorg);
        if(!empty($paramgeral) && $paramgeral['DSARQPOLPRIV']) {
            $this->zhFileUploader->deleteFile($paramgeral['DSARQPOLPRIV']);
        }
        return $this->getDataset(true);
    }

    public function findPrivacyPolicy()
    {
        $data = array();
        $paramgeralRepository = RepositoryInstance::getParamgeral();
        $paramgeral = $paramgeralRepository->findParamgeral('DSARQPOLPRIV', $this->nrorg);
        if(!empty($paramgeral) && $paramgeral['DSARQPOLPRIV']) {
            return $this->getDataset(false, $paramgeral['DSARQPOLPRIV']);
        }
        return $this->getDataset(true);
    }

    public function findPrivacyPolicyByAuthentication($user)
    {
        $paramgeralRepository = RepositoryInstance::getParamgeral();
        if (file_exists('../config/oAccCustom.tek')) {
            $paramgeral = $paramgeralRepository->findPrivacyPolicyPath();
        } else {
            if($user) {
                $user = InstanceProvider::getLibUserDataRepository()->getOperatorByNmAccessOrEmail($user);
                if(empty($user)) {
                    Exception::userNotFound();
                } else {
                    $paramgeral = $paramgeralRepository->findPrivacyPolicyPathByAuthentication($user['ORGANIZATION_ID']);
                }
            } else {
                return array(array('path' => null, 'status' => false));
            }
        }
        
        if(empty($paramgeral) || empty($paramgeral['DSARQPOLPRIV'])) {
            return array(array('path' => Utilities::getPrivacyPolicyPathParameter(), 'status' => true));
        } else {
            return array(array('path' => $this->getPrivacyPolicyPath($paramgeral['DSARQPOLPRIV']), 'status' => true));
        }
    }

    /**
     * @param $documentDefault
     * @param string $pdfPath
     * @return array
     */
    private function getDataset($documentDefault, $pdfPath = '')
    {
        $data = array();
        if($documentDefault) {
            $data[] = array(
                'pdfPath' => Utilities::getPrivacyPolicyPathParameter(),
                'documentDefault' => true
            );
        } else {
            $data[] = array(
                'pdfPath' => $this->getPrivacyPolicyPath($pdfPath),
                'documentDefault' => false
            );
        }
        return $data;
    }

    public function getPrivacyPolicyPath($pdfPath)
    {
        return $pdfPath ? $this->fileServerFilesUrl . $pdfPath : null;
    }

}